@@ -13,10 +13,10 @@
  *
  */
 
-// A String class to replace all the char * manipulation. 
+#ifndef SETUP_STRING___H
+#define SETUP_STRING___H
 
-#ifndef CINSTALL_STRING_H
-#define CINSTALL_STRING_H
+// A String class to replace all the char * manipulation. 
 
 #include <stdarg.h>
 #include <sys/types.h>
@@ -58,11 +58,15 @@ public:
   String operator + (char const *) const;
   bool operator == (String const &) const;
   bool operator == (char const *) const;
+  bool operator != (String const &) const;
+  bool operator != (char const *) const;
   struct caseless { bool operator () (String const &s1, String const &s2) const
 	{
 	  return s1.casecompare (s2) < 0;
 	}};
   bool matches (String const &pattern) const;
+  String replace (char pattern, char replacement) const;
+  String replace (String const &pattern, String const &replacement) const;
     
 private:
   class _data {
@@ -107,4 +111,10 @@ String::size() const
   return theData->length;
 }
 
-#endif // CINSTALL_STRING_H
+#define __TOSTRING__(X) #X
+/* Note the layer of indirection here is needed to allow
+   stringification of the expansion of macros, i.e. "#define foo
+   bar", "TOSTRING(foo)", to yield "bar". */
+#define TOSTRING(X) __TOSTRING__(X)
+
+#endif /* SETUP_STRING___H */
