@@ -1,5 +1,6 @@
 /*
  * Copyright (c) 2000, Red Hat, Inc.
+ * Copyright (c) 2003 Robert Collins <rbtcollins@hotmail.com>
  *
  *     This program is free software; you can redistribute it and/or modify
  *     it under the terms of the GNU General Public License as published by
@@ -13,15 +14,13 @@
  *
  */
 
-#ifndef _CHOOSE_H_
-#define _CHOOSE_H_
+#ifndef SETUP_CHOOSE_H
+#define SETUP_CHOOSE_H
 
 #include "proppage.h"
+#include "package_meta.h"
+#include "PickView.h"
 
-#define CATEGORY_EXPANDED  0
-#define CATEGORY_COLLAPSED 1
-
-#ifdef __cplusplus
 
 class ChooserPage:public PropertyPage
 {
@@ -44,7 +43,24 @@ public:
   {
     return OnNext ();
   }; 
+  private:
+  void createListview ();
+  RECT getDefaultListViewSize();
+  void getParentRect (HWND parent, HWND child, RECT * r);
+  void keepClicked();
+  void logOnePackageResult(packagemeta const *aPkg);
+  void logResults();
+  void setPrompt(char const *aPrompt);
+  template<class C> bool ifChecked(int const &id, void (C::*fn)()) {
+     if (IsButtonChecked (id)) {
+       (this->*fn)();
+       return true;
+     }
+    else
+      return false;
+  }
+  template <trusts aTrust> void changeTrust();
+  PickView *chooser;
 };
 
-#endif /* __cplusplus */
-#endif /* _CHOOSE_H_ */
+#endif /* SETUP_CHOOSE_H */
