@@ -20,7 +20,7 @@
 
 #if 0
 static const char *cvsid =
-  "\n%%% $Id: desktop.cc,v 2.34 2002/11/25 22:12:08 rbcollins Exp $\n";
+  "\n%%% $Id: desktop.cc,v 2.37 2003/07/30 23:10:35 igor Exp $\n";
 #endif
 
 #include "win32.h"
@@ -182,7 +182,7 @@ make_cygwin_bat ()
 
   fprintf (bat, "%.2s\n", get_root_dir ().cstr_oneuse());
   fprintf (bat, "chdir %s\n\n",
-	   backslash (get_root_dir () + "/bin").cstr_oneuse());
+	   backslash (get_root_dir () + "/bin").replace ("%", "%%").cstr_oneuse());
 
   fprintf (bat, "bash --login -i\n");
 
@@ -387,7 +387,6 @@ DesktopSetupPage::OnBack ()
 {
   HWND h = GetHWND ();
   save_dialog (h);
-  NEXT (IDD_CHOOSE);
   return IDD_CHOOSE;
 }
 
@@ -397,8 +396,6 @@ DesktopSetupPage::OnFinish ()
   HWND h = GetHWND ();
   save_dialog (h);
   do_desktop_setup ();
-  NEXT (IDD_S_POSTINSTALL);
-  do_postinstall (GetInstance (), h);
 
   return true;
 }
