@@ -18,7 +18,7 @@
 
 #if 0
 static const char *cvsid =
-  "\n%%% $Id: download.cc,v 2.36.2.1 2003/04/07 12:50:52 maxb Exp $\n";
+  "\n%%% $Id: download.cc,v 2.38 2003/07/30 23:04:49 igor Exp $\n";
 #endif
 
 #include "download.h"
@@ -88,7 +88,7 @@ validateCachedPackage (String const &fullname, packagesource & pkgsource)
 	}
       delete thefile;
       if (count < 0)
-	throw new Exception ("__LINE__ __FILE__", String ("IO Error reading ") + pkgsource.Cached(), APPERR_IO_ERROR);
+	throw new Exception (TOSTRING(__LINE__) " " __FILE__, String ("IO Error reading ") + pkgsource.Cached(), APPERR_IO_ERROR);
       
       md5_byte_t tempdigest[16];
       md5_finish(&pns, tempdigest);
@@ -128,7 +128,7 @@ check_for_cached (packagesource & pkgsource)
 	if (validateCachedPackage (prefix + pkgsource.Canonical (), pkgsource))
 	  pkgsource.set_cached (prefix + pkgsource.Canonical ());
 	else
-	  throw new Exception ("__LINE__ __FILE__", String ("Package validation failure for ") + prefix + pkgsource.Canonical (), APPERR_CORRUPT_PACKAGE);
+	  throw new Exception (TOSTRING(__LINE__) " " __FILE__, String ("Package validation failure for ") + prefix + pkgsource.Canonical (), APPERR_CORRUPT_PACKAGE);
 	return 1;
       }
 
@@ -146,7 +146,7 @@ check_for_cached (packagesource & pkgsource)
 	  if (validateCachedPackage (fullname, pkgsource))
 	    pkgsource.set_cached (fullname );
 	  else
-	    throw new Exception ("__LINE__ __FILE__", String ("Package validation failure for ") + fullname, APPERR_CORRUPT_PACKAGE);
+	    throw new Exception (TOSTRING(__LINE__) " " __FILE__, String ("Package validation failure for ") + fullname, APPERR_CORRUPT_PACKAGE);
 	  return 1;
 	}
     }
