@@ -15,7 +15,7 @@
 
 #if 0
 static const char *cvsid =
-  "\n%%% $Id: inilintmain.cc,v 2.2 2002/05/03 11:41:30 rbcollins Exp $\n";
+  "\n%%% $Id: inilintmain.cc,v 2.3 2002/06/26 21:35:16 rbcollins Exp $\n";
 #endif
 
 #include "getopt++/GetOption.h"
@@ -41,8 +41,20 @@ yyerror (String const &s)
   return 0;
 }
 
+void
+show_help()
+{
+  cout << "inilint checks cygwin setup.ini files and reports any errors with" << endl;
+  cout << "diagnostics" << endl;
+}
+
 int
 main (int argc, char **argv)
 {
+  if (!GetOption::GetInstance().Process (argc,argv))
+    {
+      show_help();
+      return 1;
+    }
   return 0;
 }
