@@ -28,7 +28,7 @@
 
 #if 0
 static const char *cvsid =
-  "\n%%% $Id: main.cc,v 2.25.2.1 2003/04/03 23:33:15 maxb Exp $\n";
+  "\n%%% $Id: main.cc,v 2.29 2003/07/30 23:24:18 maxb Exp $\n";
 #endif
 
 #include "win32.h"
@@ -64,6 +64,8 @@ static const char *cvsid =
 #include "getopt++/GetOption.h"
 #include "getopt++/BoolOption.h"
 
+#include "UserSettings.h"
+
 int next_dialog;
 
 HINSTANCE hinstance;
@@ -220,18 +222,11 @@ private:
   Setup::SIDWrapper everyOneSID, administratorsSID, usid;
   Setup::HANDLEWrapper token;
   bool failed_;
-  struct GroupInfo {
-    GroupInfo() : failed_ (false) {}
-    void get(Setup::HANDLEWrapper &token);
-    bool failed() const {return failed_;}
-    void fail() { failed_ = true; }
-    struct {
-      PSID psid;
-      char buf[MAX_SID_LEN];
-    } gsid;
-    DWORD size;
-    bool failed_;
-  } primaryGroupInfo;
+  struct {
+    PSID psid;
+    char buf[MAX_SID_LEN];
+  } osid;
+  DWORD size;
 };
 
 void
@@ -337,16 +332,6 @@ NTSecurity::setDefaultDACL ()
     }
 }
 
-void
-NTSecurity::GroupInfo::get(Setup::HANDLEWrapper &token)
-{
-  if (!GetTokenInformation (token.theHANDLE(), TokenPrimaryGroup, &gsid, sizeof gsid, &size))
-    {
-      NoteFailedAPI ("GetTokenInformation");
-      fail();
-    }
-}
-
 void
 NTSecurity::setDefaultSecurity ()
 {
@@ -355,42 +340,20 @@ NTSecurity::setDefaultSecurity ()
   if (failed())
     return;
 
-  primaryGroupInfo.get(token);
-  if (primaryGroupInfo.failed())
-    return;
-    
-  /* Get the computer name */
-  char compname[MAX_COMPUTERNAME_LENGTH + 1];
-  DWORD size = sizeof (compname);
-  if (!GetComputerName (compname, &size))
+  /* Get the user */
+  if (!GetTokenInformation (token.theHANDLE(), TokenUser, &osid, 
+			    sizeof osid, &size))
     {
-      NoteFailedAPI("GetComputerName");
+      NoteFailedAPI("GetTokenInformation");
       return;
     }
-
-  /* Get the local domain SID */
-  SID_NAME_USE use;
-  char domain[MAX_COMPUTERNAME_LENGTH + 1];
-  char lsid[MAX_SID_LEN];
-  size = sizeof (lsid);
-  DWORD sz = sizeof (domain);
-  if (!LookupAccountName (NULL, compname, lsid, &size, 
-			  domain, &sz, &use)) 
+  /* Make it the owner */
+  if (!SetTokenInformation (token.theHANDLE(), TokenOwner, &osid, 
+			    sizeof osid))
     {
-      NoteFailedAPI("LookupAccountName");
+      NoteFailedAPI("SetTokenInformation");
       return;
     }
-  /* Create the None SID from the domain SID.
-     On NT the last subauthority of a domain is -1 and it is replaced by the RID.
-     On other systems the RID is appended. */
-  sz = *GetSidSubAuthorityCount (lsid);
-  if (*GetSidSubAuthority (lsid, sz -1) != (DWORD) -1) 
-    *GetSidSubAuthorityCount (lsid) = ++sz;
-  *GetSidSubAuthority (lsid, sz -1) = DOMAIN_GROUP_RID_USERS;
-  
-  /* See if the group is None */
-  if (!EqualSid (primaryGroupInfo.gsid.psid, lsid))
-    return;
 
   SID_IDENTIFIER_AUTHORITY sid_auth;
   sid_auth = (SID_IDENTIFIER_AUTHORITY) { SECURITY_NT_AUTHORITY };
@@ -466,10 +429,10 @@ main (int argc, char **argv)
   theLog->setFile (LOG_BABBLE, local_dir + "/setup.log.full", false);
   theLog->setFile (0, local_dir + "/setup.log", true);
 
-  next_dialog = IDD_SPLASH;
-
   log (LOG_PLAIN) << "Starting cygwin install, version " << version << endLog;
-
+  
+  UserSettings::Instance().loadAllSettings();
+  
   SplashPage Splash;
   AntiVirusPage AntiVirus;
   SourcePage Source;
@@ -543,6 +506,9 @@ main (int argc, char **argv)
   // Create the PropSheet main window
   MainWindow.Create ();
 
+  // Clean exit.. save user options.
+  UserSettings::Instance().saveAllSettings();
+
   theLog->exit (0);
   /* Keep gcc happy :} */
   return 0;
