@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2001, Robert Collins.
+ * Copyright (c) 2001, 2003 Robert Collins.
  *
  *     This program is free software; you can redistribute it and/or modify
  *     it under the terms of the GNU General Public License as published by
@@ -14,7 +14,7 @@
  */
 
 #if 0
-static const char *cvsid = "\n%%% $Id: package_meta.cc,v 2.35.2.1 2003/03/20 00:25:25 rbcollins Exp $\n";
+static const char *cvsid = "\n%%% $Id: package_meta.cc,v 2.42 2003/07/28 08:32:07 rbcollins Exp $\n";
 #endif
 
 #include "package_meta.h"
@@ -43,6 +43,7 @@ static const char *cvsid = "\n%%% $Id: package_meta.cc,v 2.35.2.1 2003/03/20 00:
 #include "package_db.h"
 
 #include <algorithm>
+#include "Generic.h"
 
 using namespace std;
 
@@ -91,6 +92,12 @@ hash::add_subdirs (String const &tpath)
 
 /*****************/
 
+void
+packagemeta::PrepareForVisit()
+{
+  packagedb().markUnVisited();
+}
+
 const
   packagemeta::_actions
 packagemeta::Default_action (0);
@@ -129,7 +136,8 @@ packagemeta::packagemeta (packagemeta const &rhs) :
   prevtimestamp (rhs.prevtimestamp), curr (rhs.curr),
   currtimestamp (rhs.currtimestamp), exp (rhs.exp),
   exptimestamp (rhs.exptimestamp), desired (rhs.desired),
-  architecture (rhs.architecture), priority (rhs.priority)
+  architecture (rhs.architecture), priority (rhs.priority),
+  visited_(rhs.visited_)
 {
   
 }
@@ -243,20 +251,25 @@ packagemeta::add_category (String const &cat)
   categories.insert (cat);
 }
 
+struct StringConcatenator : public unary_function<String const, void>{
+    StringConcatenator(String aString) : gap(aString){}
+    void operator()(String const& aString) 
+    {
+      if (result.size() != 0)
+        result += gap;
+      result += aString;
+    }
+    String result;
+    String gap;
+};
+
 String const
 packagemeta::getReadableCategoryList () const
 {
-  String result;
-  for(set<String, String::caseless>::const_iterator it = categories.begin();
-      it != categories.end(); it++)
-  {
-    if (*it == "All")
-      continue;
-    if (result.size() > 0)
-      result += ", ";
-    result += *it;
-  }
-  return result;
+  return for_each(categories.begin(), categories.end(), 
+    visit_if (
+      StringConcatenator(", "), bind1st(not_equal_to<String>(), "All"))
+              ).visitor.result;
 }
 
 static bool
@@ -276,7 +289,7 @@ packagemeta::SDesc () const
 
 /* Return an appropriate caption given the current action. */
 String 
-packagemeta::action_caption ()
+packagemeta::action_caption () const
 {
   if (!desired && installed)
     return "Uninstall";
@@ -436,6 +449,9 @@ packagemeta::set_action (packageversion const &default_version)
 int
 packagemeta::set_requirements (trusts deftrust, size_t depth)
 {
+  if (visited())
+    return 0;
+  visited(true);
   int changed = 0;
   /* handle build-depends */
   if (depth == 0 && desired.sourcePackage ().picked())
@@ -571,3 +587,103 @@ packagemeta::trustLabel(packageversion const &aVersion) const
 	return "Test";
     return "Unknown";
 }
+
+void
+packagemeta::visited(bool const &aBool)
+{
+  visited_ = aBool;
+}
+
+bool
+packagemeta::visited() const
+{
+  return visited_;
+}
+
+void
+packagemeta::logSelectionStatus() const
+{
+  packagemeta const & pkg = *this;
+  const char *trust = ((pkg.desired == pkg.prev) ? "prev"
+               : (pkg.desired == pkg.curr) ? "curr"
+               : (pkg.desired == pkg.exp) ? "test" : "unknown");
+  String action = pkg.action_caption ();
+  String const installed =
+   pkg.installed ? pkg.installed.Canonical_version () : "none";
+
+  log (LOG_BABBLE) << "[" << pkg.name << "] action=" << action << " trust=" << trust << " installed=" << installed << " src?=" << (pkg.desired && pkg.desired.sourcePackage().picked() ? "yes" : "no") << endLog;
+  if (pkg.categories.size ())
+    log (LOG_BABBLE) << "     categories=" << for_each(pkg.categories.begin(), pkg.categories.end(), StringConcatenator(", ")).result << endLog;
+#if 0
+  if (pkg.desired.required())
+  {
+    /* List other packages this package depends on */
+      Dependency *dp = pkg.desired->required;
+    String requires = dp->package.serialise ();
+    for (dp = dp->next; dp; dp = dp->next)
+       requires += String (", ") + dp->package.serialise ();
+
+   log (LOG_BABBLE) << "     requires=" << requires;
+    }
+#endif
+  pkg.logAllVersions();
+}
+
+void
+packagemeta::ScanDownloadedFiles ()
+{
+  /* Look at every known package, in all the known mirror dirs,
+   * and fill in the Cached attribute if it exists.
+   */
+  packagedb db;
+  for (vector <packagemeta *>::iterator n = db.packages.begin ();
+       n != db.packages.end (); ++n)
+    {
+      packagemeta & pkg = **n;
+      for (set<packageversion>::iterator i = pkg.versions.begin (); 
+    i != pkg.versions.end (); ++i)
+  {
+       /* scan doesn't alter operator == for packageversions */
+      const_cast<packageversion &>(*i).scan();
+     packageversion foo = *i;
+   packageversion pkgsrcver = foo.sourcePackage();
+    pkgsrcver.scan();
+      /* For local installs, if there is no src and no bin, the version
+       * is unavailable
+       */
+    if (!i->accessible() && !pkgsrcver.accessible()
+        && *i != pkg.installed)
+      {
+        if (pkg.prev == *i)
+      pkg.prev = packageversion();
+         if (pkg.curr == *i)
+      pkg.curr = packageversion();
+         if (pkg.exp == *i)
+       pkg.exp = packageversion();
+          pkg.versions.erase(i);
+         /* For now, leave the source version alone */
+        }
+  }
+    }
+  /* Don't explicity iterate through sources - any sources that aren't 
+     referenced are unselectable anyway 
+     */
+}
+
+bool
+packagemeta::hasNoCategories() const
+{
+  return categories.size() == 0;
+}
+
+void
+packagemeta::setDefaultCategories()
+{
+  add_category ("Misc");
+}
+
+void
+packagemeta::addToCategoryAll()
+{
+  add_category ("All");
+}
