@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2001, Robert Collins.
+ * Copyright (c) 2001, 2003 Robert Collins.
  *
  *     This program is free software; you can redistribute it and/or modify
  *     it under the terms of the GNU General Public License as published by
@@ -13,14 +13,14 @@
  *
  */
 
+#ifndef SETUP_PACKAGE_VERSION_H
+#define SETUP_PACKAGE_VERSION_H
+
 /* This is a package version abstrct class, that should be able to 
  * arbitrate acceess to cygwin binary packages, cygwin source package,
  * and the rpm and deb equivalents of the same.
  */
 
-#ifndef _PACKAGE_VERSION_H_
-#define _PACKAGE_VERSION_H_
-
 /* standard binary package metadata:
  * Name (ie mutt
  * Vendor Version (ie 2.5.1)
@@ -113,7 +113,7 @@ public:
   void set_sdesc (String const &);
   String const LDesc () const;
   void set_ldesc (String const &);
-  packageversion sourcePackage ();
+  packageversion sourcePackage () const;
   PackageSpecification & sourcePackageSpecification ();
   void setSourcePackageSpecification (PackageSpecification const &);
 
@@ -138,6 +138,8 @@ public:
 					*/
 
   bool accessible () const;
+  /* scan for local copies */
+  void scan();
 
   /* ensure that the depends clause is satisfied */
   int set_requirements (trusts deftrust = TRUST_CURR, size_t depth = 0);
@@ -213,4 +215,4 @@ protected:
   std::vector <Script> scripts_;
 };
 
-#endif /* _PACKAGE_VERSION_H_ */
+#endif /* SETUP_PACKAGE_VERSION_H */
