@@ -1,8 +1,5 @@
-#ifndef CINSTALL_PROPPAGE_H
-#define CINSTALL_PROPPAGE_H
-
 /*
- * Copyright (c) 2001, Gary R. Van Sickle.
+ * Copyright (c) 2001, 2002, 2003 Gary R. Van Sickle.
  *
  *     This program is free software; you can redistribute it and/or modify
  *     it under the terms of the GNU General Public License as published by
@@ -16,6 +13,9 @@
  *
  */
 
+#ifndef SETUP_PROPPAGE_H
+#define SETUP_PROPPAGE_H
+
 // This is the header for the PropertyPage class.  It works closely with the
 // PropSheet class to implement a single page of the property sheet.
 
@@ -45,6 +45,7 @@ class PropertyPage:public Window
 						 LPARAM lParam);
   static BOOL CALLBACK DialogProcReflector (HWND hwnd, UINT message,
 					    WPARAM wParam, LPARAM lParam);
+  void setTitleFont ();
 
 protected:
     virtual BOOL CALLBACK DialogProc (UINT message, WPARAM wParam,
@@ -92,9 +93,19 @@ public:
   virtual void OnActivate ()
   {
   };
+  virtual bool wantsActivation ()
+  {
+    return true;
+  };
   virtual void OnDeactivate ()
   {
   };
+
+  // Overload these to perform special processing when the user hits
+  // "Next" or "Back". Return:
+  // 0 == Go to next/previous page in sequence.
+  // -1 == Prevent wizard from changing page.
+  // Resource ID == go to a specific page specified by the resource ID.
   virtual long OnNext ()
   {
     return 0;
@@ -103,6 +114,7 @@ public:
   {
     return 0;
   };
+
   virtual bool OnFinish ()
   {
     return true;
@@ -118,4 +130,4 @@ public:
   };
 };
 
-#endif // CINSTALL_PROPPAGE_H
+#endif /* SETUP_PROPPAGE_H */
