@@ -1,5 +1,5 @@
-#ifndef CINSTALL_ROOT_H
-#define CINSTALL_ROOT_H
+#ifndef SETUP_ROOT_H
+#define SETUP_ROOT_H
 
 #include "proppage.h"
 
@@ -16,9 +16,10 @@ public:
   bool Create ();
 
   virtual void OnInit ();
+  virtual bool wantsActivation() const;
   virtual long OnNext ();
   virtual long OnBack ();
   virtual long OnUnattended ();
 };
 
-#endif // CINSTALL_ROOT_H
+#endif /* SETUP_ROOT_H */
