@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2001, Gary R. Van Sickle.
+ * Copyright (c) 2001, 2002, 2003 Gary R. Van Sickle.
  *
  *     This program is free software; you can redistribute it and/or modify
  *     it under the terms of the GNU General Public License as published by
@@ -21,8 +21,6 @@
 #include "resource.h"
 #include "cistring.h"
 #include "splash.h"
-#include "AntiVirus.h"
-#include "dialog.h"
 
 bool
 SplashPage::Create ()
@@ -38,16 +36,4 @@ SplashPage::OnInit ()
   ver.Format (IDS_VERSION_INFO, version[0] ? version : "[unknown]");
 
   ::SetWindowText (GetDlgItem (IDC_VERSION), ver.c_str ());
-
-  // Set the font for the IDC_STATIC_WELCOME_TITLE
-  SetDlgItemFont(IDC_STATIC_WELCOME_TITLE, "Ariel", 12, FW_BOLD);
 }
-
-long
-SplashPage::OnNext()
-{
-  if (!AntiVirus::Show())
-    return IDD_SOURCE;
-  return 0;
-}
-
