@@ -1,6 +1,3 @@
-#ifndef CINSTALL_SPLASH_H
-#define CINSTALL_SPLASH_H
-
 /*
  * Copyright (c) 2001, Gary R. Van Sickle.
  *
@@ -16,6 +13,9 @@
  *
  */
 
+#ifndef SETUP_SPLASH_H
+#define SETUP_SPLASH_H
+
 // This is the header for the SplashPage class.  Since the splash page
 // has little to do, there's not much here.
 
@@ -33,11 +33,10 @@ public:
 
   bool Create ();
   virtual void OnInit ();
-  virtual long OnNext ();
   long OnUnattended ()
   {
     return 0;
   };
 };
 
-#endif // CINSTALL_SPLASH_H
+#endif /* SETUP_SPLASH_H */
