@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2001, Gary R. Van Sickle.
+ * Copyright (c) 2001, 2002, 2003 Gary R. Van Sickle.
  *
  *     This program is free software; you can redistribute it and/or modify
  *     it under the terms of the GNU General Public License as published by
@@ -20,6 +20,7 @@
 #include <windows.h>
 #include "window.h"
 #include "String++.h"
+#include "RECTWrapper.h"
 
 ATOM Window::WindowClassAtom = 0;
 HINSTANCE Window::AppInstance = NULL;
@@ -61,13 +62,15 @@ Window::FirstWindowProcReflector (HWND hwnd, UINT uMsg, WPARAM wParam,
       wnd = reinterpret_cast<Window *>(((LPCREATESTRUCT)lParam)->lpCreateParams);
 
       // Set a backreference to this class instance in the HWND.
-      SetWindowLongPtr (hwnd, GWL_USERDATA, (LONG_PTR) wnd);
+      SetWindowLongPtr (hwnd, GWL_USERDATA, reinterpret_cast<LONG_PTR>(wnd));
 
       // Set a new WindowProc now that we have the peliminaries done.
       // We could instead simply do the contents of Window::WindowProcReflector
       // in the 'else' clause below, but this way we eliminate an unnecessary 'if/else' on
       // every message.  Yeah, it's probably not worth the trouble.
       SetWindowLongPtr (hwnd, GWL_WNDPROC, (LONG_PTR) & Window::WindowProcReflector);
+      // Finally, store the window handle in the class.
+      wnd->WindowHandle = hwnd;
     }
   else
   {
@@ -85,20 +88,22 @@ Window::WindowProcReflector (HWND hwnd, UINT uMsg, WPARAM wParam,
   Window *This;
 
   // Get our this pointer
-  This = (Window *) GetWindowLongPtr (hwnd, GWL_USERDATA);
+  This = reinterpret_cast<Window *>(GetWindowLongPtr (hwnd, GWL_USERDATA));
 
   return This->WindowProc (uMsg, wParam, lParam);
 }
 
-bool Window::Create (Window * parent, DWORD Style)
+bool
+Window::Create (Window * parent, DWORD Style)
 {
   // First register the window class, if we haven't already
-  if (RegisterWindowClass () == false)
+  if (registerWindowClass () == false)
     {
       // Registration failed
       return false;
     }
 
+  // Save our parent, we'll probably need it eventually.
   Parent = parent;
 
   // Create the window instance
@@ -131,7 +136,8 @@ bool Window::Create (Window * parent, DWORD Style)
   return true;
 }
 
-bool Window::RegisterWindowClass ()
+bool
+Window::registerWindowClass ()
 {
   if (WindowClassAtom == 0)
     {
@@ -204,6 +210,12 @@ Window::MoveWindow(long x, long y, long w, long h, bool Repaint)
   return ::MoveWindow (WindowHandle, x, y, w, h, Repaint);
 }
 
+bool
+Window::MoveWindow(const RECTWrapper &r, bool Repaint)
+{
+  return ::MoveWindow (WindowHandle, r.left, r.top, r.width(), r.height(), Repaint);
+}
+
 void
 Window::CenterWindow ()
 {
@@ -250,18 +262,14 @@ Window::CenterWindow ()
   MoveWindow (p.x, p.y, WindowWidth, WindowHeight);
 }
 
-LRESULT Window::WindowProc (UINT uMsg, WPARAM wParam, LPARAM lParam)
+LRESULT
+Window::WindowProc (UINT uMsg, WPARAM wParam, LPARAM lParam)
 {
-  switch (uMsg)
-    {
-    default:
-      return DefWindowProc (WindowHandle, uMsg, wParam, lParam);
-    }
-
-  return 0;
+  return DefWindowProc (WindowHandle, uMsg, wParam, lParam);
 }
 
-bool Window::MessageLoop ()
+bool
+Window::MessageLoop ()
 {
   MSG
     msg;
@@ -285,13 +293,14 @@ Window::PostMessage (UINT uMsg, WPARAM wParam, LPARAM lParam)
   ::PostMessage (GetHWND (), uMsg, wParam, lParam);
 }
 
-UINT Window::IsButtonChecked (int nIDButton) const
+UINT
+Window::IsButtonChecked (int nIDButton) const
 {
-  return::IsDlgButtonChecked (GetHWND (), nIDButton);
+  return ::IsDlgButtonChecked (GetHWND (), nIDButton);
 }
 
 bool
-  Window::SetDlgItemFont (int id, const TCHAR * fontname, int Pointsize,
+Window::SetDlgItemFont (int id, const TCHAR * fontname, int Pointsize,
 			  int Weight, bool Italic, bool Underline,
 			  bool Strikeout)
 {
@@ -322,7 +331,7 @@ bool
       return false;
     }
 
-  // Set the new fint, and redraw any text which was already in the item.
+  // Set the new font, and redraw any text which was already in the item.
   SendMessage (ctrl, WM_SETFONT, (WPARAM) hfnt, TRUE);
 
   // Save it for later.
